@@ -43,66 +43,63 @@ class CloudErrorReporting(GoogleCloudPilotAPI):
 class CloudErrorExplorer(DiscoveryMixin, GoogleCloudPilotAPI):
     def __init__(self):
         super().__init__(
-            serviceName='clouderrorreporting',
-            version='v1beta1',
+            serviceName="clouderrorreporting",
+            version="v1beta1",
             cache_discovery=False,
         )
 
     def get_events(
-            self,
-            error_id: str = None,
-            service_name: str = None,
-            service_version: str = None,
-            resource_type: str = None,
-            project_id: str = None,
+        self,
+        error_id: str = None,
+        service_name: str = None,
+        service_version: str = None,
+        resource_type: str = None,
+        project_id: str = None,
     ):
         params = dict(
             projectName=self._project_path(project_id=project_id),
             groupId=error_id,
         )
         if service_name:
-            params['serviceFilter_service'] = service_name
+            params["serviceFilter_service"] = service_name
         if service_version:
-            params['serviceFilter_version'] = service_version
+            params["serviceFilter_version"] = service_version
         if resource_type:
-            params['serviceFilter_resourceType'] = resource_type
+            params["serviceFilter_resourceType"] = resource_type
 
         yield from self._paginate(
             method=self.client.projects().events().list,
             params=params,
-            result_key='errorEvents',
+            result_key="errorEvents",
         )
 
     def get_errors(
-            self,
-            service_name: str = None,
-            service_version: str = None,
-            resource_type: str = None,
-            project_id: str = None,
+        self,
+        service_name: str = None,
+        service_version: str = None,
+        resource_type: str = None,
+        project_id: str = None,
     ):
         params = dict(
             projectName=self._project_path(project_id=project_id),
         )
         if service_name:
-            params['serviceFilter_service'] = service_name
+            params["serviceFilter_service"] = service_name
         if service_version:
-            params['serviceFilter_version'] = service_version
+            params["serviceFilter_version"] = service_version
         if resource_type:
-            params['serviceFilter_resourceType'] = resource_type
+            params["serviceFilter_resourceType"] = resource_type
 
         items = self._paginate(
             method=self.client.projects().groupStats().list,
             params=params,
-            result_key='errorGroupStats',
+            result_key="errorGroupStats",
         )
         for item in items:
-            yield {
-                'id': item['group']['groupId'],
-                **item
-            }
+            yield {"id": item["group"]["groupId"], **item}
 
 
 __all__ = (
-    'CloudErrorReporting',
-    'CloudErrorExplorer',
+    "CloudErrorReporting",
+    "CloudErrorExplorer",
 )
